@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.38';
+$BankAccount::Validator::UK::VERSION   = '0.39';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { BankAccount::Validator::UK::Rule
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/customer-support/modulus-checking>
-It currently supports the document L<v4.80|https://www.vocalink.com/media/2920/vocalink-validating-account-numbers-v480.pdf> dated 6th March 2018.
+It currently supports the document L<v4.90|https://www.vocalink.com/media/3004/vocalink-validating-account-numbers-v490.pdf> dated 27th April 2018.
 
 Institutions covered by this document are below:
 
